/**
 * the instant messenger will check for and display instant messages
 */
var GTXInstantMessenger = {
	/**
	 * url extension for check url
	 */
	CHECK_URL_APPENDIX: "&do=27",
	
	/**
	 * check interval
	 */
	CHECK_INTERVAL: 10000,
	
	/**
	 * url to check for new messages
	 */
	checkUrl: null,
	
	/**
	 * the id of the message currently displayed
	 */
	msgId: null,
	
	/**
	 * i18n translations
	 */	
	i18n: null,
	
	/**
	 * initializes the instant messenger and kicks off the check interval
	 * @param string session tag
	 * @param obj i18n object
	 * @return void
	 */
	init: function(stag, i18n) {
		this.checkUrl = stag + this.CHECK_URL_APPENDIX;
		this.i18n = i18n;
		jQuery(document.body).append('<div id="instantMessage"><h2>' + this.i18n.message + '</h2><p class="from" />'
			+ '<p class="message" /><p><button id="instantMessageButton">Ok</button></p></div>');
		jQuery(document.body).append('<img id="instantMessageIcon" src="?do=11&module=system&img=notification.gif" alt="'
			+ this.i18n.message + '" title="' + this.i18n.message + '"/>');
		jQuery('#instantMessageButton').click(function() {
		  GTXInstantMessenger.confirmMessage();
		});
		this.check();
	},

	/**
	 * check for new messages
	 * @return void
	 */
	check: function() {
		var that = this;
		setTimeout(function() {
			jQuery.post(that.checkUrl, null, function(data) {
				that.message(data);
			}, "json");
			that.check();
		}, this.CHECK_INTERVAL);
	},
	
	/**
	 * display messages if valid
	 * depends on global variable top.isTreeSmall
	 * @param obj json data object {id, from, msg}
	 * @return void
	 */
	message: function(data) {
		if (data.msg == "") {
			return;
		}

		this.msgId = data.id;
		
		// hooray! we've go a message
		jQuery("#treeTable").fadeTo("normal", .4);
		jQuery("#instantMessage .from").text(data.from);
		jQuery("#instantMessage .message").text(data.msg);
		
		// toggle display of the message
		if (top.isTreeSmall) {
			jQuery("#instantMessageIcon").fadeIn("fast");
		} else {
			jQuery("#instantMessage").fadeIn("fast");
		}
	},
	
	/**
	 * confirm the current message
	 * @return void
	 */
	confirmMessage: function() {
		jQuery("#instantMessage").fadeOut("fast");
		jQuery("#instantMessageIcon").fadeOut("fast");
		jQuery("#treeTable").fadeTo("normal", 1);
		jQuery.get(this.checkUrl + "&confirm=" + this.msgId);
		this.msgId = null;
	},
	
	/**
	 * toggle display depending on global variable top.isTreeSmall
	 * @return void
	 */
	toggleTree: function() {
		if (top.isTreeSmall && this.msgId) {
			jQuery("#instantMessage").fadeOut("fast");
			jQuery("#instantMessageIcon").fadeIn("normal");
		} else if (!top.isTreeSmall && this.msgId) {
			jQuery("#instantMessage").fadeIn("normal");
			jQuery("#instantMessageIcon").fadeOut("fast");
		}
	}
};